| Title: | Companion Package for WSBIM2122 Course |
|---|---|
| Description: | Companion package for the WSBIM2122 course, distributing data and general documentation, and making course administration easier. |
| Authors: | Laurent Gatto [aut, cre] (ORCID: <https://orcid.org/0000-0002-1520-2268>) |
| Maintainer: | Laurent Gatto <[email protected]> |
| License: | GPL-3 |
| Version: | 0.4.1 |
| Built: | 2026-05-19 09:52:27 UTC |
| Source: | https://github.com/UCLouvain-CBIO/rWSBIM2122 |
A simple gene expression data in two groups. (Based on the sleep
data).
gexpgexp
An object of class data.frame with 20 rows and 3 columns.
data(gexp) gexpdata(gexp) gexp
Factorial design (2 factors with 2 levels each) with gene expression for 5 genes and 12 samples.
lmdatalmdata
An object of class matrix (inherits from array) with 5 rows and 12 columns.
data(lmdata, verbose = TRUE) lmdata lmannotdata(lmdata, verbose = TRUE) lmdata lmannot
A function used for its side effect. It creates the directory and files for the shell lesson.
prepare_shell(shell_dir = "wsbim2122_data", rm_dir = FALSE)prepare_shell(shell_dir = "wsbim2122_data", rm_dir = FALSE)
shell_dir |
|
rm_dir |
|
Invisibly returns TRUE.
Laurent Gatto
Package version
rWSBIM2122version()rWSBIM2122version()
## check the package version that is currently installed rWSBIM2122version()## check the package version that is currently installed rWSBIM2122version()